@@ -19,8 +19,6 @@ use Yahoo::Marketing::CreditCardInfo;
 
 
 
-my $section = 'sandbox';
-
 sub SKIP_CLASS {
     my $self = shift;
     # 'not running post tests' is a true value
@@ -32,7 +30,7 @@ sub SKIP_CLASS {
 sub test_get_account_balance : Test(2) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $balance = $ysm_ws->getAccountBalance(
         accountID => $ysm_ws->account,
@@ -46,7 +44,7 @@ sub test_add_money_and_get_account_balance : Test(5) {
 
     return 'skipping add money and get account balance test, less danger of playing with real money';
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $balance = $ysm_ws->getAccountBalance(
         accountID => $ysm_ws->account,
@@ -80,7 +78,7 @@ sub test_add_money_and_get_account_balance : Test(5) {
 sub test_get_and_set_charge_amount : Test(3) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $charge_amount = $ysm_ws->getChargeAmount( accountID => $ysm_ws->account );
     ok( defined( $charge_amount ) );
@@ -108,12 +106,12 @@ sub test_get_and_set_charge_amount : Test(3) {
 sub test_get_and_set_active_credit_card : Test(2) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $active_payment_method_id = $ysm_ws->getActiveCreditCard( accountID => $ysm_ws->account );
     ok( $active_payment_method_id );
 
-    my $vault_service = Yahoo::Marketing::VaultService->new->parse_config( section => $section );
+    my $vault_service = Yahoo::Marketing::VaultService->new->parse_config( section => $self->section );
 
     my @payment_methods = $vault_service->getPaymentMethods;
 
@@ -133,7 +131,7 @@ sub test_get_and_set_active_credit_card : Test(2) {
 sub test_set_get_and_delete_continent_block_list : Test(9) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my @continents;
 
@@ -182,7 +180,7 @@ sub test_set_get_and_delete_continent_block_list : Test(9) {
 sub test_get_account : Test(3) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $account = $ysm_ws->getAccount( accountID => $ysm_ws->account );
 
@@ -194,7 +192,7 @@ sub test_get_account : Test(3) {
 sub test_get_accounts : Test(2) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my @accounts = $ysm_ws->getAccounts;
 
@@ -209,7 +207,7 @@ sub test_get_accounts : Test(2) {
 sub test_get_account_status : Test(2) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $account_status = $ysm_ws->getAccountStatus( accountID => $ysm_ws->account );
 
@@ -220,7 +218,7 @@ sub test_get_account_status : Test(2) {
 sub test_update_account : Test(7) {
     my $self = shift;
 
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $account = $ysm_ws->getAccount( accountID => $ysm_ws->account );
     ok( $account );
@@ -253,7 +251,9 @@ sub test_update_account : Test(7) {
 
 
 sub test_update_account_status : Test(3) {
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my ( $self ) = @_;
+
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     my $account_status = $ysm_ws->getAccountStatus( accountID => $ysm_ws->account );
     ok( $account_status );
@@ -272,7 +272,9 @@ sub test_update_account_status : Test(3) {
 }
 
 sub test_set_get_delete_blocked_domain_list : Test(8) {
-    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $section );
+    my ( $self ) = @_;
+
+    my $ysm_ws = Yahoo::Marketing::AccountService->new->parse_config( section => $self->section );
 
     ok( $ysm_ws->deleteBlockedDomainListForAccount( accountID => $ysm_ws->account ) );
 
