@@ -9,13 +9,14 @@ use Test::More;
 
 use Yahoo::Marketing::AdResponse;
 
-sub test_can_create_ad_response_and_set_all_fields : Test(5) {
+sub test_can_create_ad_response_and_set_all_fields : Test(6) {
 
     my $ad_response = Yahoo::Marketing::AdResponse->new
                                                   ->ad( 'ad' )
                                                   ->editorialReasons( 'editorial reasons' )
                                                   ->errors( 'errors' )
                                                   ->operationSucceeded( 'operation succeeded' )
+                                                  ->warnings( 'warnings' )
                    ;
 
     ok( $ad_response );
@@ -24,6 +25,7 @@ sub test_can_create_ad_response_and_set_all_fields : Test(5) {
     is( $ad_response->editorialReasons, 'editorial reasons', 'can get editorial reasons' );
     is( $ad_response->errors, 'errors', 'can get errors' );
     is( $ad_response->operationSucceeded, 'operation succeeded', 'can get operation succeeded' );
+    is( $ad_response->warnings, 'warnings', 'can get warnings' );
 
 };
 
